@@ -28,12 +28,12 @@ import os.path
 LIBDIR = '/usr/lib'
 PKGDATADIR = '/usr/share/pitivi'
 PIXMAPDIR = '/usr/share/pixmaps'
-pitivi_version = '0.13.2.3'
+pitivi_version = '0.13.3'
 APPNAME = 'PiTiVi'
 PYGTK_REQ = '2.14.0'
 PYGST_REQ = '0.10.16'
 GST_REQ = '0.10.24'
-GNONLIN_REQ = '0.10.12.3'
+GNONLIN_REQ = '0.10.13'
 PYCAIRO_REQ = '1.0.0'
 
 def _get_root_dir():
