@@ -76,7 +76,7 @@ def get_env_default(var, default):
 
 def get_dir(path, autocreate=True):
     if autocreate and not os.path.exists(path):
-        os.mkdir(path)
+        os.makedirs(path)
     return path
 
 def get_dirs(glob):
@@ -138,8 +138,10 @@ class GlobalSettings(Signallable):
     options = {}
     environment = set()
     defaults = {}
+    __signals__ = {}
 
     def __init__(self, **kwargs):
+        Signallable.__init__(self)
         self._config = SafeConfigParser()
         self._readSettingsFromGlobalConfiguration()
         self._readSettingsFromConfigurationFile()
@@ -405,7 +407,7 @@ class StreamEncodeSettings(object):
                     self.output_stream = get_stream_for_caps(p.get_caps().copy())
                     self.output_stream.pad_name = p.name_template
 
-    def __repr__(self):
+    def __str__(self):
         return "<StreamEncodeSettings %s>" % self.encoder
 
 class RenderSettings(object):
@@ -425,7 +427,7 @@ class RenderSettings(object):
         self.muxer = muxer
         self.muxersettings = muxersettings
 
-    def __repr__(self):
+    def __str__(self):
         return "<RenderSettings %s [%d streams]>" % (self.muxer, len(self.settings))
 
 class ExportSettings(Signallable, Loggable):
@@ -493,14 +495,21 @@ class ExportSettings(Signallable, Loggable):
 
     def getVideoDescription(self):
         """ Returns a human-readable markup-ed string describing the video properties """
-        res = "%d x %d <i>pixels</i> at %.2f <i>fps</i> <i>(%s)</i>"
-        return res % (self.videowidth, self.videoheight,
-                      float(self.videorate), self.vencoder)
+        res = "%d x %d <i>pixels</i> at %.2f <i>fps</i>" % (self.videowidth,
+                self.videoheight, float(self.videorate))
+        if self.vencoder is not None:
+            res += " <i>(%s)</i>" % self.vencoder
+
+        return res
 
     def getAudioDescription(self):
         """ Returns a human-readable markup-ed string describing the audio properties """
-        res = "%d channels at %d <i>Hz</i> (%d <i>bits</i>) <i>(%s)</i>"
-        return res % (self.audiochannels, self.audiorate, self.audiodepth, self.aencoder)
+        res = "%d channels at %d <i>Hz</i> (%d <i>bits</i>)" % \
+                (self.audiochannels, self.audiorate, self.audiodepth)
+        if self.aencoder is not None:
+            res += " <i>(%s)</i>" % self.aencoder
+
+        return res
 
     def getAudioCaps(self):
         """ Returns the GstCaps corresponding to the audio settings """
