@@ -136,6 +136,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         self._createUI()
         self._prev_duration = 0
         self.shrink = True
+        self.rate = gst.Fraction(1,1)
         self._seeker = Seeker(80)
         self._seeker.connect('seek', self._seekerSeekCb)
 
@@ -154,7 +155,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
 
         # timeline ruler
         self.ruler = ruler.ScaleRuler(self.hadj)
-        self.ruler.set_size_request(0, 35)
+        self.ruler.set_size_request(0, 25)
         self.ruler.set_border_width(2)
         self.ruler.connect("key-press-event", self._keyPressEventCb)
         self.attach(self.ruler, 1, 2, 0, 1, yoptions=0)
@@ -299,7 +300,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
                 focus = self._temp_objects[0]
                 self._move_context = MoveContext(self.timeline,
                         focus, set(self._temp_objects[1:]))
-            self._move_temp_source(x, y)
+            self._move_temp_source(self.hadj.props.value + x, y)
         return True
 
     def _dragLeaveCb(self, unused_layout, unused_context, unused_tstamp):
@@ -318,7 +319,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         focus = self._temp_objects[0]
         self._move_context = MoveContext(self.timeline,
                 focus, set(self._temp_objects[1:]))
-        self._move_temp_source(x, y)
+        self._move_temp_source(self.hadj.props.value + x, y)
         self._move_context.finish()
         self.app.action_log.commit()
         context.drop_finish(True, timestamp)
@@ -368,7 +369,8 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         self._position = position
         self.ruler.timelinePositionChanged(position)
         self._canvas._position = position
-        self.scrollToPlayhead()
+        if self._state == gst.STATE_PLAYING:
+            self.scrollToPlayhead()
 
     def stateChanged(self, state):
         self._state = state
@@ -382,8 +384,6 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         return False
 
     def scrollToPosition(self, position):
-        if not self._state == gst.STATE_PLAYING:
-            return
         if position > self.hadj.upper:
             # we can't perform the scroll because the canvas needs to be
             # updated
@@ -403,6 +403,7 @@ class Timeline(gtk.Table, Loggable, Zoomable):
             self._controls.timeline = self.timeline
             self._canvas.timeline = self.timeline
             self._canvas.zoomChanged()
+            self.ruler.setProjectFrameRate(self.project.getSettings().videorate)
             self.ruler.zoomChanged()
             self._settingsChangedCb(self.project)
 
@@ -410,7 +411,9 @@ class Timeline(gtk.Table, Loggable, Zoomable):
 
     @handler(project, "settings-changed")
     def _settingsChangedCb(self, project):
-        self.rate = float(1 / self.project.getSettings().videorate)
+        rate = self.project.getSettings().videorate
+        self.rate = float(1 / rate)
+        self.ruler.setProjectFrameRate(rate)
 
 ## Timeline callbacks
 
@@ -481,9 +484,6 @@ class Timeline(gtk.Table, Loggable, Zoomable):
         self.actiongroup.set_visible(False)
         gtk.Vbox.hide(self)
 
-    def _computeZoomRatio(self, index):
-        return self.zoom_levels[index]
-
     def _zoomInCb(self, unused_action):
         Zoomable.zoomIn()
 
